@@ -23,11 +23,15 @@ require 'spec_helper'
 describe 'cinder::backup::swift' do
 
   let :default_params do
-    { :backup_swift_url             => 'http://localhost:8080/v1/AUTH_',
+    { :backup_swift_url             => '<SERVICE DEFAULT>',
+      :backup_swift_auth_url        => '<SERVICE DEFAULT>',
       :backup_swift_container       => 'volumes_backup',
       :backup_swift_object_size     => '<SERVICE DEFAULT>',
       :backup_swift_retry_attempts  => '<SERVICE DEFAULT>',
       :backup_swift_retry_backoff   => '<SERVICE DEFAULT>',
+      :backup_swift_user_domain     => '<SERVICE_DEFAULT>',
+      :backup_swift_project_domain  => '<SERVICE_DEFAULT>',
+      :backup_swift_project         => '<SERVICE_DEFAULT>',
       :backup_compression_algorithm => '<SERVICE DEFAULT>' }
   end
 
@@ -43,16 +47,21 @@ describe 'cinder::backup::swift' do
     it 'configures cinder.conf' do
       is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.swift')
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_url').with_value(p[:backup_swift_url])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_auth_url').with_value(p[:backup_swift_auth_url])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_container').with_value(p[:backup_swift_container])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_object_size').with_value(p[:backup_swift_object_size])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_retry_attempts').with_value(p[:backup_swift_retry_attempts])
       is_expected.to contain_cinder_config('DEFAULT/backup_swift_retry_backoff').with_value(p[:backup_swift_retry_backoff])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_user_domain').with_value(p[:backup_compression_algorithm])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project_domain').with_value(p[:backup_compression_algorithm])
+      is_expected.to contain_cinder_config('DEFAULT/backup_swift_project').with_value(p[:backup_compression_algorithm])
       is_expected.to contain_cinder_config('DEFAULT/backup_compression_algorithm').with_value(p[:backup_compression_algorithm])
     end
 
     context 'when overriding default parameters' do
       before :each do
         params.merge!(:backup_swift_url => 'https://controller2:8080/v1/AUTH_')
+        params.merge!(:backup_swift_auth_url => 'https://controller2:35357')
         params.merge!(:backup_swift_container => 'toto')
         params.merge!(:backup_swift_object_size => '123')
         params.merge!(:backup_swift_retry_attempts => '99')
@@ -61,6 +70,7 @@ describe 'cinder::backup::swift' do
       end
       it 'should replace default parameters with new values' do
         is_expected.to contain_cinder_config('DEFAULT/backup_swift_url').with_value(p[:backup_swift_url])
+        is_expected.to contain_cinder_config('DEFAULT/backup_swift_auth_url').with_value(p[:backup_swift_auth_url])
         is_expected.to contain_cinder_config('DEFAULT/backup_swift_container').with_value(p[:backup_swift_container])
         is_expected.to contain_cinder_config('DEFAULT/backup_swift_object_size').with_value(p[:backup_swift_object_size])
         is_expected.to contain_cinder_config('DEFAULT/backup_swift_retry_attempts').with_value(p[:backup_swift_retry_attempts])
@@ -70,20 +80,16 @@ describe 'cinder::backup::swift' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts({:processorcount => 8}))
+      end
+
+      it_configures 'cinder backup with swift'
     end
-
-    it_configures 'cinder backup with swift'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    it_configures 'cinder backup with swift'
   end
 
 end
