@@ -4,7 +4,6 @@ describe 'cinder::setup_test_volume' do
 
   it { is_expected.to contain_package('lvm2').with(
         :ensure  => 'present',
-        :require => 'Package[cinder]'
       ) }
 
   it 'should contain volume creation execs' do
@@ -15,4 +14,10 @@ describe 'cinder::setup_test_volume' do
     is_expected.to contain_exec('pvcreate /dev/loop2')
     is_expected.to contain_exec('vgcreate cinder-volumes /dev/loop2')
   end
+
+  it 'should set 0640 permissions for cinder-volumes' do
+    is_expected.to contain_file('/var/lib/cinder/cinder-volumes').with(
+        :mode => '0640'
+    )
+  end
 end
