@@ -55,7 +55,7 @@ describe 'cinder::backend::rbd' do
       is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /env CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/init/cinder-volume.override',
-        :notify  => 'Service[cinder-volume]')
+        :notify  => 'Anchor[cinder::service::begin]')
     end
 
     context 'with another RBD backend' do
@@ -97,6 +97,15 @@ describe 'cinder::backend::rbd' do
       end
     end
 
+    context 'rbd backend with cinder type' do
+      before do
+        params.merge!({:manage_volume_type => true})
+      end
+      it 'should create type with properties' do
+        should contain_cinder_type('rbd-ssd').with(:ensure => :present, :properties => ['volume_backend_name=rbd-ssd'])
+      end
+    end
+
   end
 
   describe 'with RedHat' do
@@ -118,7 +127,7 @@ describe 'cinder::backend::rbd' do
       is_expected.to contain_file_line('set initscript env rbd-ssd').with(
         :line    => /export CEPH_ARGS=\"--id test\"/,
         :path    => '/etc/sysconfig/openstack-cinder-volume',
-        :notify  => 'Service[cinder-volume]')
+        :notify  => 'Anchor[cinder::service::begin]')
     end
   end
 
