@@ -50,4 +50,13 @@ describe 'cinder::backend::san' do
     end
   end
 
+  context 'san backend with cinder type' do
+    before do
+      params.merge!({:manage_volume_type => true})
+    end
+    it 'should create type with properties' do
+      should contain_cinder_type('mysan').with(:ensure => :present, :properties => ['volume_backend_name=mysan'])
+    end
+  end
+
 end
