@@ -8,12 +8,12 @@ describe 'Puppet::Type.type(:cinder_config)' do
 
   it 'should autorequire the package that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'cinder')
-    catalog.add_resource package, @cinder_config
+    anchor = Puppet::Type.type(:anchor).new(:name => 'cinder::install::end')
+    catalog.add_resource anchor, @cinder_config
     dependency = @cinder_config.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@cinder_config)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
